@@ -1,6 +1,6 @@
 from PyQt6.QtWidgets import QMenu
-from PyQt6.Qsci import QsciScintilla, QsciLexer, QsciScintillaBase, QsciMacro
-from PyQt6.QtGui import QColor, QFontMetrics, QFont, QCursor
+from PyQt6.Qsci import QsciScintilla, QsciScintillaBase, QsciMacro
+from PyQt6.QtGui import QFontMetrics, QFont, QCursor
 from PyQt6.QtCore import pyqtSignal
 from jdTextEdit.gui.BannerWidgets.EditorconfigBanner import EditorconfigBanner
 from jdTextEdit.api.LanguageBase import LanguageBase
@@ -77,20 +77,11 @@ class CodeEdit(QsciScintilla):
         self.env.editorSignals.editorInit.emit(self)
 
     def updateStatusBar(self):
-        if self.isPreview or not hasattr(self.env,"mainWindow"):
+        if self.isPreview or not hasattr(self.env, "mainWindow"):
             return
-        self.env.mainWindow.pathLabel.setText(self.filePath)
-        self.env.mainWindow.encodingLabel.setText(self.usedEncoding)
-        self.env.mainWindow.lexerLabel.setText(self.languageName)
-        self.env.mainWindow.cursorPosLabel.setText(self.cursorPosString)
-        if self.eolMode() == QsciScintilla.EolMode.EolWindows:
-            self.env.mainWindow.eolLabel.setText("CRLF")
-        elif self.eolMode() == QsciScintilla.EolMode.EolUnix:
-            self.env.mainWindow.eolLabel.setText("LF")
-        elif self.eolMode() == QsciScintilla.EolMode.EolMac:
-            self.env.mainWindow.eolLabel.setText("CR")
+        self.env.mainWindow.updateStatusBar()
 
-    def setLanguage(self,lang: LanguageBase):
+    def setLanguage(self, lang: LanguageBase):
         """
         Sets the Language.
         :param lang: The Language
@@ -102,7 +93,7 @@ class CodeEdit(QsciScintilla):
         if not self.isPreview:
             self.languageName = lang.getName()
             self.updateStatusBar()
-            if not hasattr(self.env,"mainWindow"):
+            if not hasattr(self.env, "mainWindow"):
                 return
             self.env.mainWindow.updateSelectedLanguage()
         self.updateSettings(self.settings)
@@ -134,7 +125,7 @@ class CodeEdit(QsciScintilla):
                 tabWidget.setTabIcon(self.tabid,self.env.documentUnsavedIcon)
             else:
                 tabWidget.setTabIcon(self.tabid,self.env.documentSavedIcon)
-        except:
+        except Exception:
             pass
 
     def textEdited(self):
@@ -164,16 +155,14 @@ class CodeEdit(QsciScintilla):
                 self.env.mainWindow.cutMenubarItem.setEnabled(False)
                 self.env.mainWindow.copyMenubarItem.setEnabled(False)
                 self.env.mainWindow.deleteMenubarItem.setEnabled(False)
-        except:
+        except Exception:
             pass
 
     def updateCursor(self, line, pos):
         #self.SendScintilla(QsciScintillaBase.SCI_INDICATORFILLRANGE,0,10)
         self.cursorPosLine = line
         self.cursorPosIndex = pos
-        if not self.isPreview:
-            self.cursorPosString = self.env.translate("mainWindow.statusBar.cursorPosLabel") % (line + 1, pos + 1)
-            self.updateStatusBar()
+        self.updateStatusBar()
 
     def marginClickCallback(self, margin, line):
         if margin == 1:
@@ -188,7 +177,7 @@ class CodeEdit(QsciScintilla):
             self.bookmarkList.append(line)
 
     def updateEolMenu(self):
-        if self.isPreview or not hasattr(self.env,"mainWindow"):
+        if self.isPreview or not hasattr(self.env, "mainWindow"):
             return
         self.env.mainWindow.eolModeWindows.setChecked(False)
         self.env.mainWindow.eolModeUnix.setChecked(False)
@@ -250,7 +239,7 @@ class CodeEdit(QsciScintilla):
             self.env.mainWindow.redoMenubarItem.setEnabled(False)
         self.editSelectionChanged()
         self.updateEncodingMenu()
-        if not hasattr(self.env,"mainWindow"):
+        if not hasattr(self.env, "mainWindow"):
             return
         self.env.mainWindow.updateSelectedLanguage()
 
@@ -294,7 +283,7 @@ class CodeEdit(QsciScintilla):
         else:
             try:
                 modificationTime = os.path.getmtime(path)
-            except:
+            except Exception:
                 modificationTime = 0
         fileChangedBannerVisible = self.container.isFileChangedBannerVisible()
         data = {
@@ -365,7 +354,7 @@ class CodeEdit(QsciScintilla):
         if self.settings.editorConfigTabWidth:
             try:
                 self.custom_settings["editTabWidth"] = int(config["indent_size"])
-            except:
+            except Exception:
                 pass
         if "tab_width" in config and self.settings.editorConfigTabWidth:
             self.custom_settings["editTabWidth"] = int(config["tab_width"])
