@@ -1,12 +1,31 @@
-from PyQt5.QtWidgets import QWidget, QCheckBox, QVBoxLayout
+from PyQt6.QtWidgets import QLabel, QWidget, QCheckBox, QVBoxLayout
 from jdTextEdit.api.SettingsTabBase import SettingsTabBase
+from PyQt6.QtCore import  QCoreApplication
 from jdTextEdit.Settings import Settings
 
-class EditorconfigTab(QWidget,SettingsTabBase):
-    def __init__(self,env):
+
+try:
+    import editorconfig
+except ModuleNotFoundError:
+    pass
+
+
+class EditorconfigTab(QWidget, SettingsTabBase):
+    def __init__(self, env):
         super().__init__()
         self.env = env
 
+        editorconfigNotFoundLabel = QLabel(QCoreApplication.translate("EditorconfigTab", "The editorconfig module was not found"))
+        editorconfigNotFoundLabel.setStyleSheet("""
+            border-radius: 1px;
+            border-style: solid;
+            border-width: 1px;
+            border-color: darkred;
+            background: orangered;
+            color: black;
+            font-weight: bold;
+        """)
+
         self.useEditorConfig = QCheckBox(env.translate("settingsWindow.editorconfig.checkBox.useEditorConfig"))
         self.useIndentStyle = QCheckBox(env.translate("settingsWindow.editorconfig.checkBox.useIndentStyle"))
         self.tabWidth = QCheckBox(env.translate("settingsWindow.editorconfig.checkBox.tabWidth"))
@@ -18,6 +37,13 @@ class EditorconfigTab(QWidget,SettingsTabBase):
         self.useEditorConfig.stateChanged.connect(self.toogleCheckBoxEnabled)
 
         mainLayout = QVBoxLayout()
+
+        try:
+            editorconfig
+        except NameError:
+            mainLayout.addWidget(editorconfigNotFoundLabel)
+            self.useEditorConfig.setEnabled(False)
+
         mainLayout.addWidget(self.useEditorConfig)
         mainLayout.addWidget(self.useIndentStyle)
         mainLayout.addWidget(self.tabWidth)
@@ -30,7 +56,11 @@ class EditorconfigTab(QWidget,SettingsTabBase):
         self.setLayout(mainLayout)
 
     def toogleCheckBoxEnabled(self):
-        enabled =  bool(self.useEditorConfig.checkState())
+        try:
+            editorconfig
+            enabled = self.useEditorConfig.isChecked()
+        except NameError:
+            enabled = False
         self.useIndentStyle.setEnabled(enabled)
         self.tabWidth.setEnabled(enabled)
         self.endOfLine.setEnabled(enabled)
@@ -38,7 +68,7 @@ class EditorconfigTab(QWidget,SettingsTabBase):
         self.insertNewline.setEnabled(enabled)
         self.showBanner.setEnabled(enabled)
 
-    def updateTab(self,settings: Settings):
+    def updateTab(self, settings: Settings):
         self.useEditorConfig.setChecked(settings.useEditorConfig)
         self.useIndentStyle.setChecked(settings.editorConfigUseIndentStyle)
         self.tabWidth.setChecked(settings.editorConfigTabWidth)
@@ -48,14 +78,14 @@ class EditorconfigTab(QWidget,SettingsTabBase):
         self.showBanner.setChecked(settings.editorConfigShowBanner)
         self.toogleCheckBoxEnabled()
 
-    def getSettings(self,settings: Settings):
-         settings.useEditorConfig = bool(self.useEditorConfig.checkState())
-         settings.editorConfigUseIndentStyle = bool(self.useIndentStyle.checkState())
-         settings.editorConfigTabWidth = bool(self.tabWidth.checkState())
-         settings.editorConfigEndOfLine = bool(self.endOfLine.checkState())
-         settings.editorConfigTrimWhitespace = bool(self.trimWhitespace.checkState())
-         settings.editorConfigInsertNewline = bool(self.insertNewline.checkState())
-         settings.editorConfigShowBanner = bool(self.showBanner.checkState())
+    def getSettings(self, settings: Settings):
+        settings.set("useEditorConfig",self.useEditorConfig.isChecked())
+        settings.set("editorConfigUseIndentStyle",self.useIndentStyle.isChecked())
+        settings.set("editorConfigTabWidth",self.tabWidth.isChecked())
+        settings.set("editorConfigEndOfLine",self.endOfLine.isChecked())
+        settings.set("editorConfigTrimWhitespace",self.trimWhitespace.isChecked())
+        settings.set("editorConfigInsertNewline",self.insertNewline.isChecked())
+        settings.set("editorConfigShowBanner",self.showBanner.isChecked())
 
     def title(self) -> str:
         return self.env.translate("settingsWindow.editorconfig")
